@@ -15,7 +15,7 @@
 (custom-add-loads 'frames '("imenu"))
 (custom-add-loads 'shell-directories '("shell"))
 (custom-add-loads 'programming '("compile"))
-(custom-add-loads 'compilation '("compile" "auto-autoloads"))
+(custom-add-loads 'compilation '("compile"))
 (custom-add-loads 'comint-source '("comint"))
 (custom-add-loads 'maint '("add-log"))
 (custom-add-loads 'edmacro '("edmacro"))
