@@ -2,7 +2,7 @@
 
 ;; Copyright (C) 1994 Free Software Foundation, Inc.
 
-;; Author: Jamie Zawinski <jwz@netscape.com>
+;; Author: Jamie Zawinski <jwz@jwz.org>
 ;; Maintainer: XEmacs Development Team
 ;; Keywords: comm, extensions
 
@@ -31,11 +31,11 @@
 ;;  Sun Jun 12 04:19:30 1994 by sandy on ibm550.sissa.it
 ;;    Added support for password histories and (provide 'passwd)
 ;;    (jwz says: this "history" thing is completely undocumented, you loser!)
-;; 2-Jan-95 (mon); 4:13 AM by jwz@netscape.com
+;; 2-Jan-95 (mon); 4:13 AM by jwz@jwz.org
 ;;    Fixed Sandy's extreme keymap bogosity.  Made it invert the screen when
 ;;    reading securely (this could be better; maybe use red text or something
 ;;    instead...)
-;; 9-Jul-95 (fri); 4:55 AM by jwz@netscape.com
+;; 9-Jul-95 (fri); 4:55 AM by jwz@jwz.org
 ;;    Made it work with XEmacs 19.12.
 ;; 7-Jul-95 by cthomp@cs.uiuc.edu
 ;;    Added variable to control inverting frame when keyboard grabbed
@@ -307,41 +307,35 @@ characters are typed.  There's not currently a way around this."
 (defvar passwd-face-data nil)
 (defun passwd-secure-display ()
   ;; Inverts the screen - used to indicate secure input, like xterm.
-  (cond
-   ((and passwd-invert-frame-when-keyboard-grabbed
-	 (fboundp 'set-face-foreground))
+  (when passwd-invert-frame-when-keyboard-grabbed
     (setq passwd-face-data
-	  (delq nil (mapcar (function
-			     (lambda (face)
-			       (let ((fg (face-foreground face))
-				     (bg (face-background face)))
-				 (if (or fg bg)
-				     (if (fboundp 'color-name)
-					 (list face
-					       (color-name fg)
-					       (color-name bg))
-				       (list face fg bg))
-				   nil))))
-			    (face-list)
-			      )))
+	  (delq nil (mapcar
+		     (lambda (face)
+		       (let ((fg (face-foreground-instance 
+				  face (selected-frame) nil 
+				  'no-fallback))
+			     (bg (face-background-instance
+				  face (selected-frame) nil
+				  'no-fallback)))
+			 (if (and fg bg)
+			     (list face fg bg)
+			   nil)))
+		     (face-list))))
     (let ((rest passwd-face-data))
       (while rest
 	(set-face-foreground (nth 0 (car rest)) (nth 2 (car rest)) (selected-frame))
 	(set-face-background (nth 0 (car rest)) (nth 1 (car rest)) (selected-frame))
 	(setq rest (cdr rest))))))
-  nil)
 
 (defun passwd-insecure-display ()
   ;; Undoes the effect of `passwd-secure-display'.
-  (cond
-   (passwd-invert-frame-when-keyboard-grabbed
+  (when passwd-invert-frame-when-keyboard-grabbed
     (while passwd-face-data
       (set-face-foreground (nth 0 (car passwd-face-data))
 			   (nth 1 (car passwd-face-data)) (selected-frame))
       (set-face-background (nth 0 (car passwd-face-data))
 			   (nth 2 (car passwd-face-data)) (selected-frame))
-      (setq passwd-face-data (cdr passwd-face-data)))
-    nil)))
+      (setq passwd-face-data (cdr passwd-face-data)))))
 
 (defun passwd-grab-keyboard ()
   (cond ((not (and (fboundp 'x-grab-keyboard) ; lemacs 19.10+
